@@ -4,8 +4,6 @@
 # part of this implementation was inspired by package 'umapr'
 # https://github.com/ropenscilabs/umapr
 
-
-
 #' Create a umap embedding using python package umap-learn
 #'
 #' @keywords internal
@@ -15,12 +13,12 @@
 #' @importFrom stats runif
 #' 
 #' @return list, one element of which is matrix with embedding coordinates
-umap.learn = function(d, config) {
+umap.learn <- function(d, config) {
   check.learn.available()
 
   # get an update config object
   # that includes a vector of arguments for umap-learn
-  config = detect.umap.learn(config)
+  config <- detect.umap.learn(config)
 
   message.w.date(
     paste0("calling umap-learn (v", config$umap_learn_version, ")"),
@@ -31,22 +29,21 @@ umap.learn = function(d, config) {
   
   # adjust values in config to please python type checkers
   if (is.na(config$random_state)) {
-    config$random_state= as.integer(runif(1, 0, 2^30))
+    config$random_state <- as.integer(runif(1, 0, 2^30))
   }
-  config$verbose = as.integer(0 + as.logical(config$verbose))
+  config$verbose <- as.integer(0 + as.logical(config$verbose))
 
   # construct python object and create embedding
-  wo.NA = names(config[!is.na(config)])
-  UMAP = do.call(python.umap$UMAP,
-                 config[intersect(wo.NA, config$umap_learn_args)])
-  embedding = UMAP$fit_transform(d)
-  rownames(embedding) = rownames(d)
+  wo.NA <- names(config[!is.na(config)])
+  UMAP <- do.call(python.umap$UMAP,
+                  config[intersect(wo.NA, config$umap_learn_args)])
+  embedding <- UMAP$fit_transform(d)
+  rownames(embedding) <- rownames(d)
   message.w.date("done", config$verbose)
   
   list(layout=embedding, UMAP=UMAP, config=config)
 }
 
-
 #' predict embedding of new data given an existing umap object
 #'
 #' @keywords internal
@@ -55,7 +52,7 @@ umap.learn = function(d, config) {
 #' @param data matrix with new data
 #'
 #' @return matrix with embedding coordinates
-umap.learn.predict = function(umap, data) {
+umap.learn.predict <- function(umap, data) {
   check.learn.available()
 
   if (!"UMAP" %in% names(umap)) {
@@ -65,23 +62,20 @@ umap.learn.predict = function(umap, data) {
     umap.error("components UMAP is corrupt")
   }
   
-  config = detect.umap.learn(umap$config)
+  config <- detect.umap.learn(umap$config)
   message.w.date(
     paste0("calling umap-learn (v", config$umap_learn_version, ")"),
     config$verbose)
-  # perform the fit
-  embedding = umap$UMAP$transform(data)
-  rownames(embedding) = rownames(data)
+  embedding <- umap$UMAP$transform(data)
+  rownames(embedding) <- rownames(data)
   message.w.date("done", config$verbose)
   
   embedding  
 }
 
-
 # ############################################################################
 # Helper functions 
 
-
 #' adjust config depending on umap-learn version
 #'
 #' @keywords internal
@@ -89,18 +83,18 @@ umap.learn.predict = function(umap, data) {
 #' @param config list with settings
 #'
 #' @return config list with set umap_learn_args
-detect.umap.learn = function(config) {
+detect.umap.learn <- function(config) {
   
   if (!identical(config$umap_learn_args, NA)) {
     return (config)
   }
   
-  learn.version = as.character(python.umap$"__version__")
-  config$umap_learn_version = learn.version
+  learn.version <- as.character(python.umap$"__version__")
+  config$umap_learn_version <- learn.version
   # get a main version number from the detail version
-  main.version = paste(strsplit(learn.version, "\\.")[[1]][1:2], collapse=".")
+  main.version <- paste(strsplit(learn.version, "\\.")[[1]][1:2], collapse=".")
   
-  args.version = list(
+  args.version <- list(
     "0.2" = c("n_neighbors", "n_components", "metric", "n_epochs", "alpha",
               "init", "spread", "min_dist", "set_op_mix_ratio",
               "local_connectivity", "bandwidth", "gamma",
@@ -147,32 +141,30 @@ detect.umap.learn = function(config) {
               "output_dens", "disconnection_distance",
               "precomputed_knn")
   )
-  latest.name = "0.5"
-  args.version$latest = args.version[[latest.name]]
+  latest.name <- "0.5"
+  args.version$latest <- args.version[[latest.name]]
   
   if (main.version %in% names(args.version)) {    
-    config$umap_learn_args = args.version[[main.version]]
+    config$umap_learn_args <- args.version[[main.version]]
   } else {
-    version.msg = c("Detected umap-learn ", learn.version, " ",
-                    "but last supported version is ", latest.name, ";\n",
-                    "setting arguments to match version ", latest.name, ".\n",
-                    "To override this behavior, ",
-                    "set config$umap_learn_args manually.")
+    version.msg <- c("Detected umap-learn ", learn.version, " ",
+                     "but last supported version is ", latest.name, ";\n",
+                     "setting arguments to match version ", latest.name, ".\n",
+                     "To override this behavior, ",
+                     "set config$umap_learn_args manually.")
     warning(version.msg)
-    config$umap_learn_args = args.version$latest
+    config$umap_learn_args <- args.version$latest
   }
-  config$umap_learn_args = intersect(config$umap_learn_args, names(config))
+  config$umap_learn_args <- intersect(config$umap_learn_args, names(config))
   
   config
 }
 
-
 #' check whether python module is available, abort if not
 #' @keywords internal
 #' @noRd
-check.learn.available = function() {
+check.learn.available <- function() {
   if (is.null(python.umap)) {
     umap.error("python package umap-learn is not available")
   }
 }
-
